@@ -113,6 +113,19 @@ class Client(object):
                          urlencode({'regex': regexp, 'status': status_code}))
         return r.status_code
 
+    def basic_authentication(self, domain, username, password):
+        """
+        This add automatic basic authentication
+        :Args:
+         - domain: domain to set authentication credentials for
+         - username: valid username to use when authenticating
+         - password: valid password to use when authenticating
+         """
+        r = requests.post(url='%s/proxy/%s/auth/basic/%s' % (self.host, self.port, domain),
+                          data=json.dumps({'username': username, 'password': password}),
+                          headers={'content-type': 'application/json'})
+        return r.status_code
+
     LIMITS = {
         'upstream_kbps': 'upstreamKbps',
         'downstream_kbps': 'downstreamKbps',
@@ -143,6 +156,19 @@ class Client(object):
                          urlencode(params))
         return r.status_code
 
+    def remap_hosts(self, address, ip_address):
+        """
+        Remap the hosts for a specific URL
+        :Args:
+         - address - url that you wish to remap
+         - ip_address - IP Address that will handle all traffic for the address passed in
+        """
+        assert address is not None and ip_address is not None
+        r = requests.post('%s/proxy/%s/hosts' % (self.host, self.port), 
+                         json.dumps({address: ip_address}),
+                          headers={'content-type': 'application/json'})
+        return r.status_code
+
     def close(self):
         """
         shuts down the proxy and closes the port
